==> wls-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsForeignJmsDestinationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsForeignJmsDestination;

/**
 * Creates a {@link WlsForeignJmsDestination foreign JMS destination}.
 */
@SuppressWarnings("serial")
public class CreateWlsForeignJmsDestinationStep extends SimpleWlstExecutingStep {

	public static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-foreign-destination.py";

	public CreateWlsForeignJmsDestinationStep(WlsDomain domain, WlsForeignJmsDestination foreignDestination) {
		super("Create Foreign Destination " + foreignDestination + " in domain " + domain, domain, SCRIPT_RESOURCE_PATH, getArgs(foreignDestination));
	}

	private static String[] getArgs(WlsForeignJmsDestination destination) {
		List<String> args = new ArrayList<String>();
		args.add(destination.getParentForeignServer().getParentModule().getName());
		args.add(destination.getParentForeignServer().getName());
		args.add(destination.getName());
		args.add(destination.getLocalJNDIName());
		args.add(destination.getRemoteJNDIName());
		return args.toArray(new String[args.size()]);
	}

}

==> wls-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/CreateWlsForeignJmsDestinationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsForeignJmsDestination;

/**
 * Creates a {@link WlsForeignJmsDestination Foreign JMS Destination}.
 */
@SuppressWarnings("serial")
public class CreateWlsForeignJmsDestinationStep extends SimpleWlstExecutingStep {

	public static final String SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-foreign-jms-destination.py";

	public CreateWlsForeignJmsDestinationStep(WlsDomain domain, String jmsModuleName, WlsForeignJmsDestination foreignJmsDestination) {
		super("Create Foreign JMS Destination " + foreignJmsDestination + " on Foreign JMS Server " + foreignJmsDestination.getForeignJmsServer()
				+ " in JMS Module + " + jmsModuleName + " on domain " + domain, domain, SCRIPT_RESOURCE_PATH, jmsModuleName, foreignJmsDestination
				.getForeignJmsServer().getName(), foreignJmsDestination.getName(), foreignJmsDestination.getLocalJndiName(), foreignJmsDestination
				.getRemoteJndiName());
	}

}
